from tkinter import *


class DetailsInput():
    def __init__(self):
        self.top = Tk()
        self.top.geometry("300x200+500+500")
        self._api_token = StringVar()
        self._api_secret = StringVar()
        self._collection = StringVar()
        L1 = Label(self.top, text="API Token")
        L1.pack()
        E1 = Entry(self.top, bd =5, textvariable=self._api_token)
        E1.pack()
        L2 = Label(self.top, text="API Secret")
        L2.pack()
        E2 = Entry(self.top, bd =5, textvariable=self._api_secret)
        E2.pack()
        L3 = Label(self.top, text="Collection ID")
        L3.pack()
        E3 = Entry(self.top, bd =5, textvariable=self._collection)
        E3.insert(END, 'N:collection:0eed07e7-d147-4a2c-9411-1ea8f9ceffa5')
        E3.pack()
        B = Button(self.top, text='Retrieve all files', command=self.finish)
        B.pack()       
        self.top.mainloop()

    def finish(self):
        self.api_token   = self._api_token.get()
        self.api_secret  = self._api_secret.get()
        self.collection  = self._collection.get()
        self.top.destroy()

    def values(self):
        return self.api_token, self.api_secret, self.collection




import requests
from blackfynn import Blackfynn
from .config import API_TOKEN, API_SECRET
import os
import sys
from .ui import DetailsInput
import progressbar

def env_keys_valid():
    if API_TOKEN != 'local-api-key' and API_SECRET != 'local-secret-key':
        return True
    return False

def arg_valid():
    if len(sys.argv) == 1:
        return False
    if len(sys.argv[1].split('-')) == 5 and len(sys.argv[2].split('-')) == 5:
        return True
    return False

def run():

    if env_keys_valid():
        api_token = API_TOKEN
        api_secret = API_SECRET
        collection = sys.argv[1]
    elif arg_valid():
        api_token = sys.argv[1]
        api_secret = sys.argv[2]
        collection = sys.argv[3]
    elif len(sys.argv) == 1:
        ui = DetailsInput()
        api_token, api_secret, collection = ui.values()

    bf = Blackfynn(api_token=api_token,api_secret=api_secret)
    print(f'Connected to Blackfynn')
    print(f'Looking for Collection...')
    col = bf.get(collection)
    print(f'Collection found. Staring file downloads...')
    try:
        os.mkdir(col.name)
    except FileExistsError:
        pass

    for item in progressbar.progressbar(col.items):
        for file in item.files:
            file_type = '.' + file.s3_key.split('.')[-1]
            s3_url = file.url
            response = requests.get(s3_url)
            if response.status_code == 200:
                sys.stdout.write(f'\rDownloading file: {file.name}')
                f = open(col.name + '/' + file.name + file_type, 'wb')
                f.write(response.content)
                sys.stdout.flush()




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="collectiondbf",
    version="0.1.0",
    author="Jesse Khorasanee",
    author_email="jessekhorasanee@gmail.com",
    description="Download all files in a Blackfynn collection via command line or gui",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    packages=setuptools.find_packages(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Science/Research",
    ],
    install_requires=[
         'blackfynn',
         'requests',
        'progressbar2'
    ],
    python_requires='>=3.6',
)